@@ -1,19 +1,22 @@
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Optional
 
 from strawberry.utils.cached_property import cached_property
 
 from .exception import StrawberryException
-from .exception_source import ExceptionSource
 from .utils.source_finder import SourceFinder
 
 if TYPE_CHECKING:
     from strawberry.types.fields.resolver import StrawberryResolver
 
+    from .exception_source import ExceptionSource
+
 
 class MissingReturnAnnotationError(StrawberryException):
     """The field is missing the return annotation"""
 
-    def __init__(self, field_name: str, resolver: "StrawberryResolver"):
+    def __init__(self, field_name: str, resolver: StrawberryResolver):
         self.function = resolver.wrapped_func
 
         self.message = (
