@@ -1,12 +1,17 @@
-from enum import EnumMeta
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional
 
 from strawberry.utils.cached_property import cached_property
 
 from .exception import StrawberryException
-from .exception_source import ExceptionSource
 from .utils.source_finder import SourceFinder
 
+if TYPE_CHECKING:
+    from enum import EnumMeta
+
+    from .exception_source import ExceptionSource
+
 
 class NotAStrawberryEnumError(StrawberryException):
     def __init__(self, enum: EnumMeta):
