@@ -16,10 +16,7 @@ from typing import (
     cast,
 )
 
-from pydantic.fields import ModelField
-
-from graphql import GraphQLResolveInfo
-
+from strawberry.annotation import StrawberryAnnotation
 from strawberry.auto import StrawberryAuto
 from strawberry.experimental.pydantic.conversion import (
     convert_pydantic_model_to_strawberry_class,
@@ -38,6 +35,10 @@ from strawberry.object_type import _process_type, _wrap_dataclass
 from strawberry.types.type_resolver import _get_fields
 from strawberry.utils.dataclasses import add_custom_init_fn
 
+if TYPE_CHECKING:
+    from graphql import GraphQLResolveInfo
+    from pydantic.fields import ModelField
+
 
 def get_type_for_field(field: ModelField, is_input: bool):
     outer_type = field.outer_type_
@@ -56,7 +57,7 @@ def _build_dataclass_creation_fields(
     auto_fields_set: Set[str],
     use_pydantic_alias: bool,
 ) -> DataclassCreationFields:
-    type_annotation = (
+    field_type = (
         get_type_for_field(field, is_input)
         if field.name in auto_fields_set
         else existing_fields[field.name].type
@@ -76,13 +77,14 @@ def _build_dataclass_creation_fields(
             graphql_name = existing_field.graphql_name
         elif field.has_alias and use_pydantic_alias:
             graphql_name = field.alias
+
         strawberry_field = StrawberryField(
             python_name=field.name,
             graphql_name=graphql_name,
             # always unset because we use default_factory instead
             default=dataclasses.MISSING,
             default_factory=get_default_factory_for_field(field),
-            type_annotation=type_annotation,
+            type_annotation=StrawberryAnnotation.from_annotation(field_type),
             description=field.field_info.description,
             deprecation_reason=(
                 existing_field.deprecation_reason if existing_field else None
@@ -91,11 +93,12 @@ def _build_dataclass_creation_fields(
                 existing_field.permission_classes if existing_field else []
             ),
             directives=existing_field.directives if existing_field else (),
+            metadata=existing_field.metadata if existing_field else {},
         )
 
     return DataclassCreationFields(
         name=field.name,
-        type_annotation=type_annotation,
+        field_type=field_type,
         field=strawberry_field,
     )
 
@@ -181,7 +184,7 @@ def type(
         all_model_fields = [
             DataclassCreationFields(
                 name=field.name,
-                type_annotation=field.type,
+                field_type=field.type,
                 field=field,
             )
             for field in extra_fields + private_fields
@@ -212,11 +215,17 @@ def type(
         if has_custom_to_pydantic:
             namespace["to_pydantic"] = cls.to_pydantic
 
+        if hasattr(cls, "resolve_reference"):
+            namespace["resolve_reference"] = cls.resolve_reference
+
         kwargs: Dict[str, object] = {}
 
-        # Python 3.10 introduces the kw_only param. If we're on an older version
-        # then generate our own custom init function
-        if sys.version_info >= (3, 10):
+        # Python 3.10.1 introduces the kw_only param to `make_dataclass`.
+        # If we're on an older version then generate our own custom init function
+        # Note: Python 3.10.0 added the `kw_only` param to dataclasses, it was
+        # just missed from the `make_dataclass` function:
+        # https://github.com/python/cpython/issues/89961
+        if sys.version_info >= (3, 10, 1):
             kwargs["kw_only"] = dataclasses.MISSING
         else:
             kwargs["init"] = False
@@ -229,7 +238,7 @@ def type(
             **kwargs,  # type: ignore
         )
 
-        if sys.version_info < (3, 10):
+        if sys.version_info < (3, 10, 1):
             add_custom_init_fn(cls)
 
         _process_type(
@@ -248,7 +257,7 @@ def type(
         cls._pydantic_type = model
 
         def from_pydantic_default(
-            instance: PydanticModel, extra: Dict[str, Any] = None
+            instance: PydanticModel, extra: Optional[Dict[str, Any]] = None
         ) -> StrawberryTypeFromPydantic[PydanticModel]:
             return convert_pydantic_model_to_strawberry_class(
                 cls=cls, model_instance=instance, extra=extra
