@@ -2,7 +2,7 @@ from typing import Callable
 
 from graphql.error import GraphQLError
 
-from strawberry.extensions import Extension
+from strawberry.extensions.base_extension import SchemaExtension
 
 
 def default_should_mask_error(_) -> bool:
@@ -10,7 +10,7 @@ def default_should_mask_error(_) -> bool:
     return True
 
 
-class MaskErrors(Extension):
+class MaskErrors(SchemaExtension):
     should_mask_error: Callable[[GraphQLError], bool]
     error_message: str
 
