@@ -1,4 +1,5 @@
-import builtins
+from __future__ import annotations
+
 import dataclasses
 import inspect
 import sys
@@ -7,6 +8,7 @@ from typing import (
     Any,
     Awaitable,
     Callable,
+    Coroutine,
     Dict,
     List,
     Mapping,
@@ -17,33 +19,38 @@ from typing import (
     Union,
     overload,
 )
-from typing_extensions import Literal
 
 from strawberry.annotation import StrawberryAnnotation
-from strawberry.arguments import StrawberryArgument
 from strawberry.exceptions import InvalidArgumentTypeError, InvalidDefaultFactoryError
 from strawberry.type import StrawberryType
-from strawberry.types.info import Info
 from strawberry.union import StrawberryUnion
 from strawberry.utils.cached_property import cached_property
 
-from .permission import BasePermission
 from .types.fields.resolver import StrawberryResolver
 
 if TYPE_CHECKING:
+    import builtins
+    from typing_extensions import Literal
+
+    from strawberry.arguments import StrawberryArgument
+    from strawberry.extensions.field_extension import FieldExtension
+    from strawberry.types.info import Info
+
     from .object_type import TypeDefinition
+    from .permission import BasePermission
 
 T = TypeVar("T")
 
-
 _RESOLVER_TYPE = Union[
     StrawberryResolver[T],
     Callable[..., T],
+    # we initially used Awaitable, but that was triggering the following mypy bug:
+    # https://github.com/python/mypy/issues/14669
+    Callable[..., Coroutine[T, Any, Any]],
     "staticmethod[T]",
     "classmethod[T]",
 ]
 
-
 UNRESOLVED = object()
 
 
@@ -60,7 +67,6 @@ def _is_generic(resolver_type: Union[StrawberryType, type]) -> bool:
 
 
 class StrawberryField(dataclasses.Field):
-    python_name: str
     type_annotation: Optional[StrawberryAnnotation]
     default_resolver: Callable[[Any, str], object] = getattr
 
@@ -79,6 +85,7 @@ class StrawberryField(dataclasses.Field):
         metadata: Optional[Mapping[Any, Any]] = None,
         deprecation_reason: Optional[str] = None,
         directives: Sequence[object] = (),
+        extensions: List[FieldExtension] = (),  # type: ignore
     ):
         # basic fields are fields with no provided resolver
         is_basic_field = not base_resolver
@@ -127,11 +134,12 @@ class StrawberryField(dataclasses.Field):
         self.is_subscription = is_subscription
 
         self.permission_classes: List[Type[BasePermission]] = list(permission_classes)
-        self.directives = directives
+        self.directives = list(directives)
+        self.extensions: List[FieldExtension] = list(extensions)
 
         self.deprecation_reason = deprecation_reason
 
-    def __call__(self, resolver: _RESOLVER_TYPE) -> "StrawberryField":
+    def __call__(self, resolver: _RESOLVER_TYPE) -> StrawberryField:
         """Add a resolver to the field"""
 
         # Allow for StrawberryResolvers or bare functions to be provided
@@ -180,7 +188,11 @@ class StrawberryField(dataclasses.Field):
         an `Info` object and running any permission checks in the resolver
         which improves performance.
         """
-        return not self.base_resolver and not self.permission_classes
+        return (
+            not self.base_resolver
+            and not self.permission_classes
+            and not self.extensions
+        )
 
     @property
     def arguments(self) -> List[StrawberryArgument]:
@@ -201,10 +213,7 @@ class StrawberryField(dataclasses.Field):
     def _set_python_name(self, name: str) -> None:
         self.name = name
 
-    # using the function syntax for property here in order to make it easier
-    # to ignore this mypy error:
-    # https://github.com/python/mypy/issues/4125
-    python_name = property(_python_name, _set_python_name)  # type: ignore
+    python_name: str = property(_python_name, _set_python_name)  # type: ignore[assignment]  # noqa: E501
 
     @property
     def base_resolver(self) -> Optional[StrawberryResolver]:
@@ -245,7 +254,6 @@ class StrawberryField(dataclasses.Field):
             if self.base_resolver is not None:
                 # Handle unannotated functions (such as lambdas)
                 if self.base_resolver.type is not None:
-
                     # Generics will raise MissingTypesForGenericError later
                     # on if we let it be returned. So use `type_annotation` instead
                     # which is the same behaviour as having no type information.
@@ -289,7 +297,7 @@ class StrawberryField(dataclasses.Field):
 
     def copy_with(
         self, type_var_map: Mapping[TypeVar, Union[StrawberryType, builtins.type]]
-    ) -> "StrawberryField":
+    ) -> StrawberryField:
         new_type: Union[StrawberryType, type] = self.type
 
         # TODO: Remove with creation of StrawberryObject. Will act same as other
@@ -356,6 +364,8 @@ def field(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    extensions: Optional[List[FieldExtension]] = None,
+    graphql_type: Optional[Any] = None,
 ) -> T:
     ...
 
@@ -373,6 +383,8 @@ def field(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    extensions: Optional[List[FieldExtension]] = None,
+    graphql_type: Optional[Any] = None,
 ) -> Any:
     ...
 
@@ -390,6 +402,8 @@ def field(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    extensions: Optional[List[FieldExtension]] = None,
+    graphql_type: Optional[Any] = None,
 ) -> StrawberryField:
     ...
 
@@ -406,6 +420,8 @@ def field(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    extensions: Optional[List[FieldExtension]] = None,
+    graphql_type: Optional[Any] = None,
     # This init parameter is used by PyRight to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -426,10 +442,12 @@ def field(
     it can be used both as decorator and as a normal function.
     """
 
+    type_annotation = StrawberryAnnotation.from_annotation(graphql_type)
+
     field_ = StrawberryField(
         python_name=None,
         graphql_name=name,
-        type_annotation=None,
+        type_annotation=type_annotation,
         description=description,
         is_subscription=is_subscription,
         permission_classes=permission_classes or [],
@@ -438,6 +456,7 @@ def field(
         default_factory=default_factory,
         metadata=metadata,
         directives=directives or (),
+        extensions=extensions or [],
     )
 
     if resolver:
