@@ -27,6 +27,8 @@ from .utils.dataclasses import add_custom_init_fn
 from .utils.str_converters import to_camel_case
 from .utils.typing import __dataclass_transform__
 
+T = TypeVar("T", bound=Type)
+
 
 def _get_interfaces(cls: Type) -> List[TypeDefinition]:
     interfaces = []
@@ -65,19 +67,26 @@ def _check_field_annotations(cls: Type):
         # If the field is a StrawberryField we need to do a bit of extra work
         # to make sure dataclasses.dataclass is ready for it
         if isinstance(field_, StrawberryField):
+            # If the field has a type override then use that instead of using
+            # the class annotations or resolver annotation
+            if field_.type_annotation is not None:
+                cls_annotations[field_name] = field_.type_annotation.annotation
+                continue
 
             # Make sure the cls has an annotation
             if field_name not in cls_annotations:
                 # If the field uses the default resolver, the field _must_ be
                 # annotated
                 if not field_.base_resolver:
-                    raise MissingFieldAnnotationError(field_name)
+                    raise MissingFieldAnnotationError(field_name, cls)
 
                 # The resolver _must_ have a return type annotation
                 # TODO: Maybe check this immediately when adding resolver to
                 #       field
                 if field_.base_resolver.type_annotation is None:
-                    raise MissingReturnAnnotationError(field_name)
+                    raise MissingReturnAnnotationError(
+                        field_name, resolver=field_.base_resolver
+                    )
 
                 cls_annotations[field_name] = field_.base_resolver.type_annotation
 
@@ -91,7 +100,7 @@ def _check_field_annotations(cls: Type):
         # dataclasses.field
         if field_name not in cls_annotations:
             # Field object exists but did not get an annotation
-            raise MissingFieldAnnotationError(field_name)
+            raise MissingFieldAnnotationError(field_name, cls)
 
 
 def _wrap_dataclass(cls: Type):
@@ -171,9 +180,6 @@ def _process_type(
     return cls
 
 
-T = TypeVar("T", bound=Type)
-
-
 @overload
 @__dataclass_transform__(
     order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
@@ -356,9 +362,25 @@ def interface(
     )
 
 
+def asdict(obj: object) -> Dict[str, object]:
+    """Convert a strawberry object into a dictionary.
+    This wraps the dataclasses.asdict function to strawberry.
+
+    Example usage:
+    >>> @strawberry.type
+    >>> class User:
+    >>>     name: str
+    >>>     age: int
+    >>> # should be {"name": "Lorem", "age": 25}
+    >>> user_dict = strawberry.asdict(User(name="Lorem", age=25))
+    """
+    return dataclasses.asdict(obj)  # type: ignore
+
+
 __all__ = [
     "TypeDefinition",
     "input",
     "interface",
     "type",
+    "asdict",
 ]
